# Generated by roxygen2: do not edit by hand

export("Author<-")
export("Boxplot<-")
export("Code<-")
export("Color<-")
export("Date<-")
export("Defaults<-")
export("Description<-")
export("Design<-")
export("Email<-")
export("Factors<-")
export("Institution<-")
export("Introduction<-")
export("Kobe<-")
export("Label<-")
export("Limit<-")
export("MPs<-")
export("MaxValue<-")
export("Metadata<-")
export("MinValue<-")
export("Misc<-")
export("OMs<-")
export("Preset<-")
export("Quilt<-")
export("RefPoints<-")
export("Spider<-")
export("Subtitle<-")
export("Target<-")
export("Time<-")
export("TimeLab<-")
export("TimeNow<-")
export("TimeTerminal<-")
export("Timeseries<-")
export("Title<-")
export("Tradeoff<-")
export("Value<-")
export(App)
export(Author)
export(Boxplot)
export(Check)
export(Code)
export(Color)
export(Date)
export(Defaults)
export(Description)
export(Design)
export(Email)
export(Factors)
export(FilterSlick)
export(Institution)
export(Introduction)
export(Kobe)
export(Label)
export(Limit)
export(MPs)
export(Make_Slick)
export(MaxValue)
export(Metadata)
export(MinValue)
export(Misc)
export(NewSlick)
export(OMs)
export(PMnorm)
export(Preset)
export(Quilt)
export(RefPoints)
export(Slick)
export(Spider)
export(Subtitle)
export(Target)
export(Time)
export(TimeLab)
export(TimeNow)
export(TimeTerminal)
export(Timeseries)
export(Title)
export(Tradeoff)
export(Update)
export(Value)
export(default_mp_colors)
export(download_casestudy)
export(get_casestudies)
export(plotBoxplot)
export(plotKobe)
export(plotQuilt)
export(plotSpider)
export(plotTimeseries)
export(plotTradeoff)
export(show)
exportClasses(Boxplot)
exportClasses(Kobe)
exportClasses(MPs)
exportClasses(OMs)
exportClasses(Quilt)
exportClasses(Slick)
exportClasses(Spider)
exportClasses(Timeseries)
exportClasses(Tradeoff)
exportMethods("Preset<-")
exportMethods(Metadata)
import(shiny)
importFrom(golem,activate_js)
importFrom(golem,add_resource_path)
importFrom(golem,bundle_resources)
importFrom(golem,favicon)
importFrom(golem,with_golem_options)
importFrom(grDevices,colors)
importFrom(grDevices,rgb)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(methods,"slot<-")
importFrom(methods,new)
importFrom(methods,slot)
importFrom(methods,slotNames)
importFrom(shiny,NS)
importFrom(shiny,shinyApp)
importFrom(shiny,tagList)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,time)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
