The Relative Scale button rescales each performance indicator shown in the plots between the maximum and minimum values of that indicator.

When Relative Scale is on, the center of the spider plot will represent the lowest value for each performance indicator, and the outside edge of the spider plot will represent the highest value for each indicator.

When Relative Scale is off, the performance indicators values are plotted directly, with 100 representing the highest score and 0 the lowest.

